@@ -1,10 +1,10 @@
-/// Call Notify::notify_one() when object is dropped.
-/// It's useful to use together with https://crates.io/crates/tokio-interruptible-future
-
 use tokio::sync::Notify;
 
+/// Deliver () when the object is dropped.
+/// It's useful to use together with https://crates.io/crates/tokio-interruptible-future
+
 pub struct NotifyDrop<'a> {
-    notify: &'a Notify
+    notify: &'a Notify,
 }
 
 impl<'a> NotifyDrop<'a> {
@@ -29,10 +29,13 @@ mod tests {
 
     #[test]
     fn no_deadlock() {
-        let n = Notify::new();
-        { // block
-            let _guard = NotifyDrop::new(&n);
-        }
-        block_on(async { n.notified().await });
+        let notify = Notify::new();
+        block_on(async {
+            let notified = notify.notified(); //.clone().await;
+            { // block
+                let _guard = NotifyDrop::new(&notify);
+            }
+            notified.await;
+        });
     }
 }
